@@ -2,7 +2,6 @@ import importlib
 import logging
 import os
 import shutil
-from pkgutil import iter_modules
 
 from django.apps import AppConfig
 from django.apps import apps
@@ -13,7 +12,6 @@ from django.core.urlresolvers import reverse
 from pkg_resources import DistributionNotFound
 from pkg_resources import get_distribution
 from pkg_resources import iter_entry_points
-from pkg_resources import resource_exists
 from semver import VersionInfo
 
 import kolibri
@@ -100,7 +98,7 @@ def initialize_plugins_and_hooks(all_classes, plugin_name):
             # Initialize the class, nothing more happens for now.
             plugin_objects.append(class_definition())
             if not was_configured and django_settings.configured:
-                raise RuntimeError(
+                raise PluginLoadsApp(
                     "Initializing plugin class {} in plugin {} caused Django settings to be configured".format(
                         class_definition.__name__, plugin_name
                     )
@@ -108,7 +106,7 @@ def initialize_plugins_and_hooks(all_classes, plugin_name):
         elif issubclass(class_definition, KolibriHook):
             class_definition.add_hook_to_registries()
             if not was_configured and django_settings.configured:
-                raise RuntimeError(
+                raise PluginLoadsApp(
                     "Initializing hook class {} in plugin {} caused Django settings to be configured".format(
                         class_definition.__name__, plugin_name
                     )
@@ -146,7 +144,7 @@ def initialize_kolibri_plugin(plugin_name):
         # Exceptions are expected to be thrown from here.
         plugin_module = importlib.import_module(plugin_name + ".kolibri_plugin")
         if not was_configured and django_settings.configured:
-            raise RuntimeError(
+            raise PluginLoadsApp(
                 "Importing plugin module {} caused Django settings to be configured".format(
                     plugin_name
                 )
@@ -154,9 +152,6 @@ def initialize_kolibri_plugin(plugin_name):
         logger.debug("Loaded kolibri plugin: {}".format(plugin_name))
         # If no exception is thrown, use this to find the plugin class.
         # Load a list of all class types in module
-        all_classes = [
-            cls for cls in plugin_module.__dict__.values() if isinstance(cls, type)
-        ]
         # Filter the list to only match the ones that belong to the module
         # and not the ones that have been imported
         plugin_package = (
@@ -164,9 +159,18 @@ def initialize_kolibri_plugin(plugin_name):
             if plugin_module.__package__
             else plugin_module.__name__.rpartition(".")[0]
         )
-        all_classes = filter(
-            lambda x: plugin_package + ".kolibri_plugin" == x.__module__, all_classes
-        )
+
+        def is_plugin_module(x):
+            return (
+                hasattr(x, "__module__")
+                and plugin_package + ".kolibri_plugin" == x.__module__
+            )
+
+        all_classes = [
+            cls
+            for cls in plugin_module.__dict__.values()
+            if is_plugin_module(cls) and isinstance(cls, type)
+        ]
         return initialize_plugins_and_hooks(all_classes, plugin_name)
 
     except ImportError as e:
@@ -203,7 +207,7 @@ def disable_plugin(plugin_name):
         if obj:
             obj.disable()
             return True
-    except PluginDoesNotExist as e:
+    except Exception as e:
         logger.error(str(e))
         logger.warning(
             "Removing '{}' from configuration in a naive way.".format(plugin_name)
@@ -309,6 +313,11 @@ class PluginUpdateManager(object):
         try:
             self._migrate_plugin(plugin_name, app_configs)
         except Exception as e:
+            logger.error(
+                "Unhandled exception while migrating {}, exception was:\n\n{}".format(
+                    plugin_name, e
+                )
+            )
             return
         if old_version:
             if VersionInfo.parse(
@@ -458,14 +467,3 @@ def iterate_plugins():
         if _can_import_plugin(name) and name not in plugins:
             plugins.add(name)
             yield name
-    for module_loader, name, is_pkg in iter_modules():
-        try:
-            if (
-                is_pkg
-                and name not in plugins
-                and resource_exists(name, "kolibri_plugin.py")
-                and _can_import_plugin(name)
-            ):
-                yield name
-        except Exception:
-            pass
